@@ -4,5 +4,7 @@ pub use app::App;
 pub mod editor;
 pub mod result_list;
 
+mod context_viewer;
 mod input_handler;
 mod scroll_offset_list;
+pub mod theme;
